==> mythgallery_0.16.orig.tar.gz: mythgallery-0.16/i18n/mythgallery_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mythgallery_0.17.orig.tar.gz: mythgallery-0.17/i18n/mythgallery_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
